ShowGuideParams class

Constructors

ShowGuideParams({required String? id, bool force = false, VoidCallback? onComplete})

Properties

force bool
Whether to skip the canShow method and forcely show the guide.
final
hashCode int
The hash code for this object.
no setterinherited
id String?
The identifier of the guide to be shown.
final
onComplete VoidCallback?
Called when the guide has been shown
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited